@@ -30,7 +30,7 @@ drawParam <- function(paramSet, maxDraw = 50, numFree = 1, misfitBounds = NULL,
             }
         })
     }))
-    
+    misfitType <- tolower(misfitType)
     stopifnot(misfitType == "f0" || misfitType == "rmsea" || misfitType == "srmr" || 
         misfitType == "all")
     
@@ -249,29 +249,32 @@ drawParam <- function(paramSet, maxDraw = 50, numFree = 1, misfitBounds = NULL,
             if (all(sapply(fullpls, validateObject))) {
                 redpls <- lapply(fullpls, reduceMatrices)
                 macsPopls <- lapply(redpls, createImpliedMACS)
-                if (!(all(is.finite(unlist(lapply(macsPopls, "[[", 2)))) && (sum(unlist(lapply(lapply(lapply(macsPopls, 
-                  "[[", 2), eigen), "[[", 1)) <= 0) == 0))) {
+                if (all(is.finite(unlist(lapply(macsPopls, "[[", 2)))) && all(unlist(lapply(lapply(lapply(macsPopls, 
+                  "[[", 2), eigen), "[[", 1)) > 0)) {
                   break
                 }
-            } else {
-                draw <- draw + 1
-                if (draw > maxDraw) {
-                  stop("Cannot obtain valid parameter set within maximum number of draws.")
-                }
-                next
-            }
-            final <- list()
-            for (i in groupLoop) {
-                final[[i]] <- list(param = redpls[[i]], misspec = NULL, misOnly = NULL)
-            }
-            return(final)
+            } 
+			draw <- draw + 1
+			if (draw > maxDraw) {
+			  stop("Cannot obtain valid parameter set within maximum number of draws.")
+			}
+			next
+            # final <- list()
+            # for (i in groupLoop) {
+                # final[[i]] <- list(param = redpls[[i]], misspec = NULL, misOnly = NULL)
+            # }
+            # return(final)
         }
         
     }
     if (draw < maxDraw) {
         final <- list()
         for (i in groupLoop) {
-            final[[i]] <- list(param = redpls[[i]], misspec = redmpls[[i]], misOnly = redmls[[i]])
+			if (misspec) {
+				final[[i]] <- list(param = redpls[[i]], misspec = redmpls[[i]], misOnly = redmls[[i]])
+			} else {
+				final[[i]] <- list(param = redpls[[i]], misspec = NULL, misOnly = NULL)
+			}
         }
         return(final)
     } else {
@@ -658,8 +661,8 @@ equalCon <- function(pls, dgen, fill=FALSE, con=NULL) {
 
 
 extractLab <- function(pls, dgen, fill=FALSE, con=NULL) {
+
 	free <- lapply(dgen, function(x) lapply(x, function(y) if(is.null(y)) { return(NULL) } else { return(slot(y, "free")) }))
-	
 	if(fill) {
 		
 		for(i in 1:length(free)) {
@@ -714,9 +717,9 @@ extractLab <- function(pls, dgen, fill=FALSE, con=NULL) {
 	free2 <- do.call(c, lapply(free, function(x) do.call(c, x)))
 	lab <- free2[is.na(suppressWarnings(as.numeric(as.vector(free2)))) & !is.na(free2)]
 	target <- unique(lab) #[duplicated(lab)])
-	
 	val <- lapply(pls, function(x) lapply(x, function(y) if(is.null(y)) { return(NULL) } else { return(y) }))
 	val2 <- do.call(c, lapply(val, function(x) do.call(c, x)))
+	val2 <- val2[match(names(free2), names(val2))]
 	realval <- val2[is.na(suppressWarnings(as.numeric(as.vector(free2)))) & !is.na(free2)]
 	realval <- realval[match(target, lab)]
 	list(target, realval, dgen)
